.. include:: ../README.rst

=============
Documentation
=============

.. toctree::
   :maxdepth: 2

   installation
   development
   usage
   contributing
   authors
   history
   API reference <boomerang>
